@@ -29,15 +29,12 @@ class PickledObject(str):
 
 
 def dbsafe_encode(value, compress_object=False, pickle_protocol=DEFAULT_PROTOCOL):
-    """
-    We use deepcopy() here to avoid a problem with cPickle, where dumps
-    can generate different character streams for same lookup value if
-    they are referenced differently.
-
-    The reason this is important is because we do all of our lookups as
-    simple string matches, thus the character streams must be the same
-    for the lookups to work properly. See tests.py for more information.
-    """
+    # We use deepcopy() here to avoid a problem with cPickle, where dumps
+    # can generate different character streams for same lookup value if
+    # they are referenced differently.
+    # The reason this is important is because we do all of our lookups as
+    # simple string matches, thus the character streams must be the same
+    # for the lookups to work properly. See tests.py for more information.
     if not compress_object:
         value = b64encode(dumps(deepcopy(value), pickle_protocol))
     else:
@@ -56,22 +53,19 @@ def dbsafe_decode(value, compress_object=False):
 class PickledObjectField(models.Field):
     """
     A field that will accept *any* python object and store it in the
-    database. PickledObjectField will optionally compress it's values if
+    database. PickledObjectField will optionally compress its values if
     declared with the keyword argument ``compress=True``.
 
     Does not actually encode and compress ``None`` objects (although you
     can still do lookups using None). This way, it is still possible to
-    use the ``isnull`` lookup type correctly. Because of this, the field
-    defaults to ``null=True``, as otherwise it wouldn't be able to store
-    None values since they aren't pickled and encoded.
-
+    use the ``isnull`` lookup type correctly.
     """
+
     __metaclass__ = models.SubfieldBase
 
     def __init__(self, *args, **kwargs):
         self.compress = kwargs.pop('compress', False)
         self.protocol = kwargs.pop('protocol', DEFAULT_PROTOCOL)
-        kwargs.setdefault('null', True)
         kwargs.setdefault('editable', False)
         super(PickledObjectField, self).__init__(*args, **kwargs)
 
@@ -148,3 +142,12 @@ class PickledObjectField(models.Field):
         # The Field model already calls get_db_prep_value before doing the
         # actual lookup, so all we need to do is limit the lookup types.
         return super(PickledObjectField, self).get_db_prep_lookup(lookup_type, value)
+
+
+# South support; see http://south.aeracode.org/docs/tutorial/part4.html#simple-inheritance
+try:
+    from south.modelsinspector import add_introspection_rule
+except ImportError:
+    pass
+else:
+    add_introspection_rules([], [r"^picklefield\.fields\.PickledObjectField"])
